@@ -1,5 +1,7 @@
 package App::dropboxapi;
-our $VERSION = '1.13';
+use strict;
+use warnings;
+our $VERSION = '1.14';
 
 =head1 NAME
 
